@@ -1,10 +1,10 @@
 #!/bin/sh
 echo 'name: libmpd
-version: 0.6.0
-id: libmpd-0.6.0-532ce7b9971e660cab01691291dc1afc
+version: 0.7.2
+id: libmpd-0.7.2-0e2e8a1bb71c34b33c286122f1c8ffdd
 
 license: LGPL
-copyright: Ben Sinclair 2005-2009, Joachim Fasting 2010, 2011
+copyright: Ben Sinclair 2005-2009, Joachim Fasting 2012
 maintainer: Joachim Fasting <joachim.fasting@gmail.com>
 stability: beta
 homepage: http://github.com/joachifm/libmpd-haskell
@@ -21,27 +21,27 @@ hidden-modules: Network.MPD.Core.Class Network.MPD.Core.Error
                 Network.MPD.Commands Network.MPD.Commands.Arg
                 Network.MPD.Commands.Parse Network.MPD.Commands.Query
                 Network.MPD.Commands.Types Network.MPD.Commands.Util
-                Network.MPD.Utils
-import-dirs: /usr/local/lib/ghc/libmpd-0.6.0
-library-dirs: /usr/local/lib/ghc/libmpd-0.6.0
-hs-libraries: HSlibmpd-0.6.0
+                Network.MPD.Util
+import-dirs: /usr/local/lib/ghc/libmpd-0.7.2
+library-dirs: /usr/local/lib/ghc/libmpd-0.7.2
+hs-libraries: HSlibmpd-0.7.2
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.3.1.0-912d55d387093f740e3bcd2ffbf1dd83
-         containers-0.4.0.0-18deac99a132f04751d862b77aab136e
-         filepath-1.2.0.0-679ac50c41ba31bfc69abf444d9852e4
-         mtl-2.0.1.0-9763a8821c812a910d327bad2c0d23b2
-         network-2.3.0.2-51cd64b57afa0471aa34f65914adc9bc
-         old-locale-1.0.0.2-6e2a3c0744e8cf4e0ac2d4e58659f7b5
-         time-1.2.0.3-57ebba2cc05370f666b7eceba5e468a9
-         utf8-string-0.3.6-41fffa08ae1349e9fe1e9be7575781f1
+depends: base-4.3.1.0-ee15f259a627d341af7c80a17e8b0e66
+         containers-0.4.0.0-f1307d32d8f4b51a1487c01f0997b6d9
+         filepath-1.2.0.0-956a4b0c127b8c317f6cac3946b0b803
+         mtl-2.0.1.0-3e464329054b7660133198d73c31aca5
+         network-2.3.0.5-8b6868c0e6dbf6adced217440d46f03d
+         old-locale-1.0.0.2-25ff1e5e0486bb3cf2cb85cb7daf8f22
+         time-1.2.0.3-ad46a3ade48e0011608895f44cc02a52
+         utf8-string-0.3.6-131bec5ed6c825184d560515f17820d3
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-libmpd-0.6.0/html/libmpd.haddock
-haddock-html: /usr/local/share/doc/hs-libmpd-0.6.0/html
+haddock-interfaces: /usr/local/share/doc/hs-libmpd-0.7.2/html/libmpd.haddock
+haddock-html: /usr/local/share/doc/hs-libmpd-0.7.2/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
